@@ -1,14 +1,22 @@
+from typing import Union
+
 from nonebot.adapters.onebot.v11 import MessageSegment
 from nonebot.adapters.onebot.v11.bot import Bot
 
-from nonebot_plugin_sky.utils_.config_loader import Nick
+from ..utils_.bot_loader import Nick
 
 
 async def chain_reply(
-        # 构造聊天记录转发消息
         bot: Bot,
-        msg: MessageSegment
-):
+        msg: Union[str, MessageSegment]
+) -> list:
+    """
+    构造聊天记录转发消息
+
+    :param bot:
+    :param msg:
+    :return:
+    """
     chain = []
 
     data = {
